## Dyadic Data Analysis Workshop 


############## Load packages ################

# first clear workspace 
rm(list = ls())

p_needed <- c("Rcpp","dplyr", "lubridate", "stringi", "devtools", "ggmap", "GGally", 
              "mosaic", "lme4", "nlme", "ppcor", "knitr", 
              "rmarkdown", "markdown", "gee", "haven",
              "psych", "foreign", "lavaan", "semPlot","FSA", "sjPlot")

packages <- rownames(installed.packages())
p_to_install <- p_needed[!(p_needed %in% packages)]

if(length(p_to_install) > 0){
  install.packages(p_to_install)
}

lapply(p_needed, library, character.only = TRUE)

install_github("RandiLGarcia/dyadr")
library(dyadr)



############## Load the data file ################


## load the TSD data 
TSD <- data.frame(read.spss(file.choose()))

## view the data 
View(TSD)

############# Setting up the variables ############

# comment before doing any analyses, run descriptives. 
# make sure your actor and partner variables have the same means, SDs, but are not perfectly correlated. 

favstats(TSD$overall_tutoring_1_00)
favstats(TSD$overall_tutoring_2_00)
favstats(TSD$ladder_now_1_00)
favstats(TSD$ladder_now_2_00)

# cor.test will give you significance level too; you can use "cor" to just get the correlation

cor.test(overall_tutoring_1_00 ~ overall_tutoring_2_00, data = TSD)
cor.test(ladder_now_1_00 ~ ladder_now_2_00, data = TSD)

# next make sure to center all continous predictors 
TSD$ladder_now_1_00C <- TSD$ladder_now_1_00 - mean(TSD$ladder_now_1_00)
TSD$ladder_now_2_00C <- TSD$ladder_now_2_00 - mean(TSD$ladder_now_2_00)

# if you want to check that centering did the job, run favstats again 
# if you are getting scientific notation and want to get rid of it, use this syntax: options(scipen = 999)
favstats(TSD$ladder_now_1_00C)

TSD$rolenum[TSD$role == "tutor"] <- 1
TSD$rolenum[TSD$role == "student"] <- -1

# first run the model assuming indistinguishable dyads
# Note: to ask for interactions in R there are 2 ways: either use ":" and specify the main effects yourself
# or use "*" and R will add the main effects automatically

indistinguishable_model  <- gls(overall_tutoring_1_00 ~ rolenum*ladder_now_1_00C, na.action=na.omit, 
                 correlation=corCompSymm (form=~1|dyad), data=TSD)
smallsummary(indistinguishable_model)
summary(indistinguishable_model)

distinguishable_model <- gls(overall_tutoring_1_00 ~ rolenum*ladder_now_1_00C,
                             data = TSD,
                             correlation = corCompSymm(form=~1|dyad),
                             weights = varIdent(form=~1|rolenum), # this is the line that tells it that you have distinguishable dyads
                             na.action = na.omit)

smallsummary(distinguishable_model)
summary(distinguishable_model)

## alternatives: lme and lmer 

##lme only accepts nested random effect; lmer handles crossed random
#effects
#lme has a convenient methof of handling heteroscedasticity; lmer doesn't.
#lme gives you p-values; lmer doesn't (there is explanation of why at 
# https://stat.ethz.ch/pipermail/r-help/2006-May/094765.html 

mixed_lme <- lme(overall_tutoring_1_00~ladder_now_1_00C*rolenum, random=~1|dyad, data=TSD); 
summary(mixed_lme)

mixed_lmer <- lmer(overall_tutoring_1_00~(1|dyad)+ladder_now_1_00C*rolenum, data=TSD );
summary(mixed_lmer)

# comment expanding the model to include partner ladder. 

apim_model <- gls(overall_tutoring_1_00 ~ rolenum*ladder_now_1_00C+ rolenum*ladder_now_2_00C,
                             data = TSD,
                             correlation = corCompSymm(form=~1|dyad),
                             weights = varIdent(form=~1|rolenum), # this is the line that tells it that you have distinguishable dyads
                             na.action = na.omit)

summary(apim_model)

## to see actor and partner effects for students and tutors separately 
# so you don't get tripped by the -1's and 1s

apim_effects <- gls(overall_tutoring_1_00 ~ role + ladder_now_1_00C:role 
                   + ladder_now_2_00C:role -1,
                   data = TSD,
                   correlation = corCompSymm(form=~1|dyad),
                   weights = varIdent(form=~1|role),
                   na.action = na.omit)

smallsummary(apim_effects)


# comment breaking the interaction down by role. 
#to do so, we need to first recode role so that the reference group is zero. 

TSD$role_tutor[TSD$role == "tutor"] <- 0
TSD$role_tutor[TSD$role == "student"] <- 1

TSD$role_student[TSD$role == "tutor"] <- 1
TSD$role_student[TSD$role == "student"] <- 0

## now we run the same syntax from the first apim model 
## but replacing role with role_student for the student model
## and with role_tutor for the tutor model 

apim_model_students <- gls(overall_tutoring_1_00 ~ role_student*ladder_now_1_00C+ role_student*ladder_now_2_00C,
                  data = TSD,
                  correlation = corCompSymm(form=~1|dyad),
                  weights = varIdent(form=~1|rolenum), # this is the line that tells it that you have distinguishable dyads
                  na.action = na.omit)

summary(apim_model_students)

apim_model_tutors <- gls(overall_tutoring_1_00 ~ role_tutor*ladder_now_1_00C+ role_tutor*ladder_now_2_00C,
                           data = TSD,
                           correlation = corCompSymm(form=~1|dyad),
                           weights = varIdent(form=~1|rolenum), # this is the line that tells it that you have distinguishable dyads
                           na.action = na.omit)

summary(apim_model_tutors)

####### Plotting the interaction between role and actor ladder ###########

actor_int<- lm(overall_tutoring_1_00 ~ ladder_now_1_00C*role, data = TSD)
summary(actor_int)
plot_model(actor_int, type = "int", mdrt.values = "meansd")


####### Plotting the interaction between role and partner ladder############
partner_int <- lm(overall_tutoring_1_00 ~ladder_now_2_00C*role, data = TSD)
summary(partner_int)
plot_model(partner_int, type = "int", mdrt.values = "meansd")


## Note that R plots are typically easier to make if you make the categorical variable 
## the factor (i.e. student and tutor as separate lines), but you can also make low and high
## ladder as the lines. It's just more complicated, but syntax is below. 

####### Same plot but with role on the X axis ##########

x <- TSD$ladder_now_1_00C
# divide into three groups
TSD$ladder_now_1_00C_3group <-
  case_when(
    x > mean(x) + sd(x) ~ "High",
    x < mean(x) + sd(x) & x > mean(x) - sd(x) ~ "Mean",
    x < mean(x) - sd(x) ~ "Low"
  )
# leave only two groups for plot
TSD <- TSD[!(TSD$ladder_now_1_00C_3group == "Mean"), ]
# plot two groups
TSD %>%
  ggplot() +
  aes(
    x = rolenum,
    y = overall_tutoring_1_00,
    group = ladder_now_1_00C_3group,
    color = ladder_now_1_00C_3group
  ) +
  geom_smooth(method = "lm") +
  theme_minimal()+
  ggtitle("Tutoring satisfaction as a function of ladder and role")

